@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply arpeggiation patterns to groups of notes
 
-our $VERSION = '0.0300';
+our $VERSION = '0.0301';
 
 use Moo;
 use strictures 2;
@@ -113,11 +113,11 @@ Music::MelodicDevice::Arpeggiation - Apply arpeggiation patterns to groups of no
 
 =head1 VERSION
 
-version 0.0300
+version 0.0301
 
 =head1 SYNOPSIS
 
-  use Music::MelodicDevice::Arpeggiation;
+  use Music::MelodicDevice::Arpeggiation ();
 
   my $arp = Music::MelodicDevice::Arpeggiation->new;
 
@@ -125,8 +125,6 @@ version 0.0300
 
   my $arped = $arp->arp([60,64,67], 1, 'updown', 3);
 
-  my $pattern = $arp->build_pattern('my-type', [60,65,67,69]); # [0,2,1]
-
 =head1 DESCRIPTION
 
 C<Music::MelodicDevice::Arpeggiation> applies arpeggiation patterns to
